@@ -1,10 +1,87 @@
 package Mail::DMARC::Report;
 {
-  $Mail::DMARC::Report::VERSION = '0.20130506';
+  $Mail::DMARC::Report::VERSION = '0.20130507';
 }
 use strict;
 use warnings;
 
+# Two Report Roles: receiver, and sender.
+# Can they use the same DB tables? Should they?
+#
+# Report receiver
+#  1. accept report via HTTP
+#     accept report via SMTP
+#  2. parse the XML message
+#  3. insert report into database
+#  4. a means to present reported data
+#
+# Report sender needs to:
+#  1. store reports
+#       open DB connection
+#       if a report for author_domain does not exist
+#          insert new report
+#       insert report record
+#
+#  2. bundle aggregated reports
+#  3. wrap the up in XML
+#  4. gzip the XML
+#  5. deliver report
+
+#   feedback => {
+#      version          => 1,  # decimal
+#      report_metadata  => {                # info about DMARC reporter
+#          report_id          => string
+#          org_name           => string     # Art Farm
+#          email              => string     # dmarc-report@theartfarm.com
+#          extra_contact_info => string     # min 0
+#          date_range         => {
+#              begin          => epoch time,
+#              end            => epoch time,
+#          },
+#          error              => string,   # min 0, max unbounded
+#      },
+#      policy_published => {
+#          domain =>   string
+#          adkim  =>   r, s
+#          aspf   =>   r, s
+#          p      =>   none, quarantine, reject
+#          sp     =>   none, quarantine, reject
+#          pct    =>   integer
+#      },
+#      record   => {
+#         row => {
+#            source_ip     =>   # IPAddress
+#            count         =>   # integer
+#            policy_evaluated => {       # min=0
+#               disposition =>           # none, quarantine, reject
+#               dkim        =>           # pass, fail
+#               spf         =>           # pass, fail
+#               reason      => {         # min 0, max unbounded
+#                   type    =>    # forwarded sampled_out ...
+#                   comment =>    # string, min 0
+#               },
+#           }
+#        },
+#        identifiers => {
+#            envelope_to    min=0
+#            envelope_from  min=1
+#            header_from    min=1
+#        },
+#        auth_results => {
+#            spf  =>  {        # min 1, max unbounded
+#                domain  =>    # min 1
+#                scope   =>    # helo, mfrom  -  min 1
+#                result  =>    # none neutral ...
+#            }                   # ( unknown -> temperror, error -> permerror )
+#            dkim   =>  {            # min 0, max unbounded
+#               domain       =>  ,   # the d= parameter in the signature
+#               selector     =>  ,   # min 0
+#               result       =>  ,   # none pass fail policy ...
+#               human_result =>      # min 0
+#            },
+#        },
+#     },
+#  };
 
 1;
 # ABSTRACT: A DMARC report object
@@ -18,18 +95,26 @@ Mail::DMARC::Report - A DMARC report object
 
 =head1 VERSION
 
-version 0.20130506
+version 0.20130507
 
 =head1 SYNOPSIS
 
 REPORT URIs
 
-=head1 EMAIL REPORTS
+=head1 12.2.1 Email
 
-   The aggregate data MUST be an XML file subjected to GZIP compression.
-   The aggregate data MUST be present using the media type "application/
-   gzip", and the filenames SHOULD be constructed using the following
-   ABNF:
+In the case of a "mailto" URI, the Mail Receiver SHOULD communicate
+reports using the method described in [STARTTLS].
+
+The message generated by the Mail Receiver must be a [MIME] formatted
+[MAIL] message.  The aggregate report itself MUST be included in one
+of the parts of the message.  A human-readable portion MAY be
+included as a MIME part (such as a text/plain part).
+
+The aggregate data MUST be an XML file subjected to GZIP compression.
+The aggregate data MUST be present using the media type "application/
+gzip", and the filenames SHOULD be constructed using the following
+ABNF:
 
      filename = receiver "!" policy-domain "!" begin-timestamp "!"
                 end-timestamp [ "!" unique-id ] "." extension
@@ -62,13 +147,13 @@ REPORT URIs
 The RFC5322.Subject field for individual report submissions SHOULD
 conform to the following ABNF:
 
-     dmarc-subject = %x52.65.70.6f.72.74 1*FWS    ; "Report"
-                     %x44.6f.6d.61.69.6e.3a 1*FWS ; "Domain:"
-                     domain-name 1*FWS            ; from RFC6376
-                     %x53.75.62.6d.69.74.74.65.72.3a ; "Submitter:"
-                     1*FWS domain-name 1*FWS
-                     %x52.65.70.6f.72.74.2d.49.44.3a ; "Report-ID:"
-                     msg-id                       ; from RFC5322
+   dmarc-subject = %x52.65.70.6f.72.74 1*FWS    ; "Report"
+                   %x44.6f.6d.61.69.6e.3a 1*FWS ; "Domain:"
+                   domain-name 1*FWS            ; from RFC6376
+                   %x53.75.62.6d.69.74.74.65.72.3a ; "Submitter:"
+                   1*FWS domain-name 1*FWS
+                   %x52.65.70.6f.72.74.2d.49.44.3a ; "Report-ID:"
+                   msg-id                       ; from RFC5322
 
 The first domain-name indicates the DNS domain name about which the
 report was generated.  The second domain-name indicates the DNS
@@ -82,9 +167,7 @@ feedback data size exceeds maximum allowable attachment sizes for
 either the generator or the consumer.  See Section 12.2.4 for further
 discussion.
 
-=head1 HTTP
-
-12.2.2.  HTTP
+=head1 12.2.2. HTTP
 
 Where an "http" or "https" method is requested in a Domain Owner's
 URI list, the Mail Receiver MAY encode the data using the
@@ -98,6 +181,10 @@ HTTP permits the use of Content-Transfer-Encoding to upload gzip
 content using the POST or PUT instruction after translating the
 content to 7-bit ASCII.
 
+=head1 12.2.3. Other Methods
+
+Other registered URI schemes may be explicitly supported in later versions.
+
 =head1 AGGREGATE REPORTS
 
 The report SHOULD include the following data:
@@ -178,11 +265,9 @@ MUST be included that contains field-value pairs such as those found
 in Section 2 of [DSN].  The fields required, which may appear in any
 order, are:
 
-Report-Date:  A [MAIL]-formatted date expression indicating when the
-    transport failure occurred.
+Report-Date:  A [MAIL]-formatted date expression indicating when the transport failure occurred.
 
-Report-Domain:  The domain-name about which the failed report was
-    generated.
+Report-Domain:  The domain-name about which the failed report was generated.
 
 Report-ID:  The Report-ID: that the report tried to use.
 
@@ -196,11 +281,9 @@ Report-Size:  The size, in bytes, of the report that was unable to be
     "https" reports might be POSTed to those URIs with a different
     size, as they have different transport and encoding requirements.
 
-Submitter:  The domain-name representing the Mail Receiver that
-    generated, but was unable to submit, the report.
+Submitter:  The domain-name representing the Mail Receiver that generated, but was unable to submit, the report.
 
-Submitting-URI:  The URI(s) to which the Mail Receiver tried, but
-    failed, to submit the report.
+Submitting-URI:  The URI(s) to which the Mail Receiver tried, but failed, to submit the report.
 
 An additional text/plain part MAY be included that gives a human-
 readable explanation of the above, and MAY also include a URI that
